#
# Configure paths and flags for the SimFQT library.
# Denis Arnaud <denis_arnaud at users dot sourceforge dot net>, July 2008
#
# Note: the SIMFQT library depends upon BOOST to build.
# Your configure.ac must therefore define appropriately the BOOST
# variables (i.e., BOOST_CFLAGS, BOOST_LIBS, BOOST_DATE_TIME_LIB).
#
# Variables set by this macro:
#  * SIMFQT_VERSION
#  * SIMFQT_CFLAGS
#  * SIMFQT_LIBS
#  * SIMFQT_SAMPLE_DIR
#

AC_DEFUN([AM_PATH_SIMFQT],
[
AC_LANG_SAVE
AC_LANG([C++])

##
AC_ARG_WITH(simfqt,
	[ --with-simfqt=PFX Prefix where SimFQT is installed (optional) ],
	    simfqt_dir="$withval",
	    simfqt_dir="")

  if test "x${SIMFQT_CONFIG+set}" != xset ; then
     if test "x$simfqt_dir" != x ; then
         SIMFQT_CONFIG="$simfqt_dir/bin/simfqt-config"
     fi
  fi

  AC_PATH_PROG(SIMFQT_CONFIG, simfqt-config, no)

  ## Check whether Boost flags and libraries are defined
  # General Boost compilation flags
  AC_MSG_CHECKING(for BOOST_CFLAGS environment variable)
  if test x"${BOOST_CFLAGS}" = x; then
	AC_MSG_RESULT([Warning: SimFQT needs Boost, and the BOOST_CFLAGS environment variable does not appear to be set. It may not be a problem, though, if your Unix distribution is standard, that is, if Boost is installed in /usr. Otherwise, the SimFQT will fail to compile.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_CFLAGS})])
  fi

  # Boost Date-Time library
  AC_MSG_CHECKING(for BOOST_DATE_TIME_LIB environment variable)
  if test x"${BOOST_DATE_TIME_LIB}" = x; then
	AC_MSG_RESULT([Warning: SimFQT needs the Boost Date-Time library, and the BOOST_DATE_TIME_LIB environment variable does not appears to be set. The SimFQT may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_DATE_TIME_LIB})])
  fi

  # Boost Program Options library
  AC_MSG_CHECKING(for BOOST_PROGRAM_OPTIONS_LIB environment variable)
  if test x"${BOOST_PROGRAM_OPTIONS_LIB}" = x; then
	AC_MSG_RESULT([Warning: SimFQT needs the Boost Program Options library, and the BOOST_PROGRAM_OPTIONS_LIB environment variable does not appears to be set. The SimFQT may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_PROGRAM_OPTIONS_LIB})])
  fi

  # Boost File System library
  AC_MSG_CHECKING(for BOOST_FILESYSTEM_LIB environment variable)
  if test x"${BOOST_FILESYSTEM_LIB}" = x; then
	AC_MSG_RESULT([Warning: SimFQT needs the Boost Date-Time library, and the BOOST_FILESYSTEM_LIB environment variable does not appears to be set. The SimFQT may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_FILESYSTEM_LIB})])
  fi

  ## SimFQT version
  min_simfqt_version=ifelse([$1], ,0.1.0,$1)
  AC_MSG_CHECKING(for SimFQT - version >= $min_simfqt_version)
  no_simfqt=""
  if test "${SIMFQT_CONFIG}" = "no" ; then
     no_simfqt=yes
     AC_MSG_RESULT([no])
  else
     SIMFQT_VERSION=`${SIMFQT_CONFIG} --version`
     SIMFQT_CFLAGS=`${SIMFQT_CONFIG} --cflags`
     SIMFQT_CFLAGS="${BOOST_CFLAGS} ${SIMFQT_CFLAGS}"
     SIMFQT_LIBS=`${SIMFQT_CONFIG} --libs`
     SIMFQT_LIBS="${BOOST_LIBS} ${BOOST_DATE_TIME_LIB} ${SIMFQT_LIBS}"
     SIMFQT_SAMPLE_DIR=`${SIMFQT_CONFIG} --sampledir`

     AC_SUBST([SIMFQT_VERSION])
     AC_SUBST([SIMFQT_CFLAGS])
     AC_SUBST([SIMFQT_LIBS])
     AC_SUBST([SIMFQT_SAMPLE_DIR])

    simfqt_major_version=`echo ${SIMFQT_VERSION} | sed 's/^\([[0-9]]*\).*/\1/'`
    if test "x${simfqt_major_version}" = "x" ; then
       simfqt_major_version=0
    fi

    simfqt_minor_version=`echo ${SIMFQT_VERSION} | \
						sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\2/'`
    if test "x${simfqt_minor_version}" = "x" ; then
       simfqt_minor_version=0
    fi

    simfqt_micro_version=`echo ${SIMFQT_VERSION} | \
          sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\3/'`
    if test "x${simfqt_micro_version}" = "x" ; then
       simfqt_micro_version=0
    fi

    ## Simple test of compilation and link
    SAVED_CPPFLAGS="${CPPFLAGS}"
    SAVED_LDFLAGS="${LDFLAGS}"
    CPPFLAGS="${CPPFLAGS} ${BOOST_CFLAGS} ${SIMFQT_CFLAGS}"
    LDFLAGS="${LDFLAGS} ${SIMFQT_LIBS}"


    AC_COMPILE_IFELSE(
		[AC_LANG_PROGRAM([[#include <simfqt/SIMFQT_Service.hpp>
				]],
				[[int i=0;]]
		)]
		,

    	[AC_MSG_RESULT([yes (${SIMFQT_VERSION})])],

	[AC_MSG_ERROR([We could not compile a simple SimFQT example. See config.log.])]
    )

    CPPFLAGS="${SAVED_CPPFLAGS}"
    LDFLAGS="${SAVED_LDFLAGS}"

  fi

AC_LANG_RESTORE
])
